require 'faraday'
require 'faraday_middleware'

module RubyUber
  class Client

    attr_accessor :server_token, :client_id, :secret

    def initialize(options)
      @server_token = options[:server_token]
      @client_id    = options[:client_id]
      @secret       = options[:secret]

      if !server_token && !oauthable?
        raise AuthenticationError,
          "Must provide either :server_token or :client_id and :secret to initialize Ruber::Client"
      end
    end

    def host
      'api.uber.com'
    end

    def base_url
      "https://#{host}/v1"
    end

    def connection
      @connection ||= Faraday.new(url: base_url) do |conn|
        conn.request    :json
        conn.response   :json
        conn.adapter    Faraday.default_adapter
      end
    end

    def get(url, params)
      connection.get(url, params) do |req|
        req.headers['Authorization'] = "Token #{server_token}"
      end
    end

    def price_estimates
      V1::PriceEstimates.new(client: self)
    end

    def products
      V1::Products.new(client: self)
    end

    def time_estimates
      V1::TimeEstimates.new(client: self)
    end

    def user_activity
      V1::UserActivity.new(client: self)
    end

    def user_profile
      V1::UserProfile.new(client: self)
    end

    private

    def oauthable?
      client_id && secret
    end

  end
end